pub enum ForgetReason {
UnknownCall,
SccWithoutSummary,
MayAliasWrite,
UnsupportedEffect,
}Expand description
Reason for conservatively forgetting relevant state.
Variants
UnknownCall
A call may modify relevant state but has no summary yet.
SccWithoutSummary
An SCC region may modify relevant state but has no summary yet.
MayAliasWrite
A write may alias relevant state.
UnsupportedEffect
A relevant statement or terminator is not supported yet.